==> 0.0.5.tar.gz: lib/create_widget/create_widget_cli.dart <==
import 'dart:async';
import 'dart:io';

import 'package:path/path.dart' as path;

import '../util/utilities.dart';

void createWidget(String widgetName) {
  stdout.write(
      'Do you want to create a common widget or a feature widget? (common/feature): ');
  String choice = stdin.readLineSync()!.toLowerCase();

  if (choice == 'common') {
    createWidgetProcess(widgetName, 'lib/core/ui/widgets', true);
  } else if (choice == 'feature') {
    stdout.write('Enter your feature name: ');
    String featureName = stdin.readLineSync()!.toLowerCase();
    Directory destinationDirectory = Directory('lib/features/$featureName');
    if (destinationDirectory.existsSync()) {
      createWidgetProcess(
          widgetName, 'lib/features/$featureName/presentation/screen', false);
    } else {
      print('Feature $featureName does not exist.');
    }
  } else {
    print('Invalid choice. Please choose "common" or "feature".');
    exit(1);
  }
}

Future<void> createWidgetProcess(
    String widgetName, String destinationPath, bool isCommon) async {
  String destinationFilePath = isCommon
      ? '$destinationPath/$widgetName.dart'
      : '$destinationPath/widgets/$widgetName.dart';
  if (doesFileExist(destinationFilePath)) {
    print(
        'File at $destinationFilePath already exists. Please choose a different widget name');
    exit(1);
  }

  String currentFilePath = Platform.script.toFilePath();
  List<String> pathSegments = currentFilePath.split(Platform.pathSeparator);
  if (pathSegments.length > 2) {
    pathSegments.removeRange(pathSegments.length - 5, pathSegments.length);
  }

  String packageName = 'jt_flutter_cli';
  String version = getPackageVersion(packageName);
  String dependencyName = '$packageName-$version';
  String pubCachePath;
  if (Platform.isWindows) {
    String userprofile = Platform.environment['USERPROFILE'] ?? '';
    print("path : $userprofile");
    pubCachePath = Platform.environment['PUB_CACHE'] ??
        path.join(userprofile, 'AppData', 'Local', 'Pub', 'Cache');
    print("cache path  : $pubCachePath");
  } else {
    pubCachePath = Platform.environment['PUB_CACHE'] ??
        path.join(Platform.environment['HOME']!, '.pub-cache');
  }
  String dependencyPath =
      path.join(pubCachePath, 'hosted', 'pub.dev', dependencyName);
  if (!Directory(dependencyPath).existsSync()) {
    print('Dependency $dependencyName not found in .pub-cache directory');
    return;
  }
  String dependencyLibPath = path.join(dependencyPath, 'lib');
  if (!Directory(dependencyLibPath).existsSync()) {
    print('Dependency $dependencyName does not contain a lib folder');
    return;
  }
  String sourceFolderPath = '$dependencyLibPath/create_widget/basic_widget';
  grantPermissions(sourceFolderPath);

  if (!Directory(sourceFolderPath).existsSync()) {
    print('Error: $sourceFolderPath folder does not exist');
    return;
  }

  try {
    destinationPath = isCommon ? destinationPath : '$destinationPath/widgets';
    await copyFolder(sourceFolderPath, destinationPath, widgetName);
    await processFiles(destinationPath, '/*', '', false);
    await processFiles(destinationPath, '*/', '', false);
    await renameFilesWithSubstring(destinationPath, 'basic_widget', widgetName);
    await processFiles(destinationPath, 'BasicWidget', widgetName, true);
    String? name = getPubspecInfo('name');
    if (name != null) {
      await processFiles(
          destinationPath, 'flutter_clean_architecture', name, false);
    }
    print('Widget $widgetName created at $destinationPath');
  } catch (e) {
    print('Error : $e');
  }
}

Future<void> copyFolder(
    String sourcePath, String destinationPath, String widgetName) async {
  Directory sourceDir = Directory(sourcePath);
  Directory destDir = Directory(destinationPath);
  if (!await destDir.exists()) {
    await destDir.create(recursive: true);
  }
  List<FileSystemEntity> contents = sourceDir.listSync();
  for (var entity in contents) {
    if (entity is File) {
      String newPath = path.join(destinationPath, path.basename(entity.path));
      await entity.copy(newPath);
    }
  }
}

==> 0.0.9.tar.gz: lib/create_widget/create_widget_cli.dart <==
import 'dart:async';
import 'dart:io';

import 'package:path/path.dart' as path;

import '../util/utilities.dart';

void createWidget(String widgetName) {
  stdout.write(
      'Do you want to create a common widget or a feature widget? (common/feature): ');
  String choice = stdin.readLineSync()!.toLowerCase();

  if (choice == 'common') {
    createWidgetProcess(widgetName, 'lib/core/ui/widgets', true);
  } else if (choice == 'feature') {
    stdout.write('Enter your feature name: ');
    String featureName = stdin.readLineSync()!.toLowerCase();
    Directory destinationDirectory = Directory('lib/features/$featureName');
    if (destinationDirectory.existsSync()) {
      createWidgetProcess(
          widgetName, 'lib/features/$featureName/presentation/screen', false);
    } else {
      print('Feature $featureName does not exist.');
    }
  } else {
    print('Invalid choice. Please choose "common" or "feature".');
    exit(1);
  }
}

Future<void> createWidgetProcess(
    String widgetName, String destinationPath, bool isCommon) async {
  String destinationFilePath = isCommon
      ? '$destinationPath/$widgetName.dart'
      : '$destinationPath/widgets/$widgetName.dart';
  if (doesFileExist(destinationFilePath)) {
    print(
        'File at $destinationFilePath already exists. Please choose a different widget name');
    exit(1);
  }

  String currentFilePath = Platform.script.toFilePath();
  List<String> pathSegments = currentFilePath.split(Platform.pathSeparator);
  if (pathSegments.length > 2) {
    pathSegments.removeRange(pathSegments.length - 5, pathSegments.length);
  }

  String packageName = 'jt_flutter_cli';
  String version = getPackageVersion(packageName);
  String dependencyName = '$packageName-$version';
  String pubCachePath;
  if (Platform.isWindows) {
    String userprofile = Platform.environment['USERPROFILE'] ?? '';
    print("path : $userprofile");
    pubCachePath = Platform.environment['PUB_CACHE'] ??
        path.join(userprofile, 'AppData', 'Local', 'Pub', 'Cache');
    print("cache path  : $pubCachePath");
  } else {
    pubCachePath = Platform.environment['PUB_CACHE'] ??
        path.join(Platform.environment['HOME']!, '.pub-cache');
  }
  String dependencyPath =
      path.join(pubCachePath, 'hosted', 'pub.dev', dependencyName);
  if (!Directory(dependencyPath).existsSync()) {
    print('Dependency $dependencyName not found in .pub-cache directory');
    return;
  }
  String dependencyLibPath = path.join(dependencyPath, 'lib');
  if (!Directory(dependencyLibPath).existsSync()) {
    print('Dependency $dependencyName does not contain a lib folder');
    return;
  }
  String sourceFolderPath = '$dependencyLibPath/create_widget/basic_widget';
  grantPermissions(sourceFolderPath);

  if (!Directory(sourceFolderPath).existsSync()) {
    print('Error: $sourceFolderPath folder does not exist');
    return;
  }

  try {
    destinationPath = isCommon ? destinationPath : '$destinationPath/widgets';
    await copyFolder(sourceFolderPath, destinationPath, widgetName);
    await renameFilesWithSubstring(destinationPath, 'basic_widget', widgetName);
    String targetFileName = isCommon ? '$widgetName.dart' : '';
    await processFiles(destinationPath, '/*', '', false,
        targetFileName: targetFileName);
    await processFiles(destinationPath, '*/', '', false,
        targetFileName: targetFileName);
    await processFiles(destinationPath, 'BasicWidget', widgetName, true,
        targetFileName: targetFileName);
    String? name = getPubspecInfo('name');
    if (name != null) {
      await processFiles(
          destinationPath, 'flutter_clean_architecture', name, false,
          targetFileName: targetFileName);
    }
    print('Widget $widgetName created at $destinationPath');
  } catch (e) {
    print('Error : $e');
  }
}

Future<void> copyFolder(
    String sourcePath, String destinationPath, String widgetName) async {
  Directory sourceDir = Directory(sourcePath);
  Directory destDir = Directory(destinationPath);
  if (!await destDir.exists()) {
    await destDir.create(recursive: true);
  }
  List<FileSystemEntity> contents = sourceDir.listSync();
  for (var entity in contents) {
    if (entity is File) {
      String newPath = path.join(destinationPath, path.basename(entity.path));
      await entity.copy(newPath);
    }
  }
}
